<?php

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
    exit( 'Direct script access denied.' );
}

class Sebian_Init{

    public function __construct(){
        add_action( 'after_setup_theme', array( $this, 'load_textdomain' ) );
        add_action( 'after_setup_theme', array( $this, 'add_theme_supports' ) );
        add_action( 'after_setup_theme', array( $this, 'register_nav_menus' ) );
        add_action( 'after_setup_theme', array( $this, 'set_default_options' ) );

        add_action( 'widgets_init', array( $this, 'widget_init' ) );

        // Add contact methods for author page.
        add_filter( 'user_contactmethods', array( $this, 'modify_contact_methods' ) );

    }

    public function load_textdomain(){
        load_theme_textdomain( 'sebian', Sebian::$template_dir_path . '/languages' );
        load_child_theme_textdomain( 'sebian', Sebian::$stylesheet_dir_path . '/languages' );
    }

    public function add_theme_supports(){
        add_theme_support( 'automatic-feed-links' );
        add_theme_support( 'title-tag' );
        add_theme_support( 'custom-header' );
        add_theme_support( 'custom-background' );
        add_theme_support( 'post-thumbnails' );
        add_theme_support( 'post-formats', array(
            'quote',
            'image',
            'video',
            'link',
            'audio',
            'gallery'
        ) );
        add_theme_support( 'menus' );
        add_theme_support( 'woocommerce');
        add_theme_support( 'wc-product-gallery-zoom');
        add_theme_support( 'wc-product-gallery-lightbox');
    }

    public function register_nav_menus(){
        register_nav_menus( array(
            'main-nav'   => esc_attr__( 'Main Navigation', 'sebian' )
        ) );
    }

    public function set_default_options(){
        if(!get_option(Sebian()->get_option_name())){
            add_option(
                Sebian()->get_option_name(),
                json_decode('{"layout":"col-2cl","body_boxed":"no","body_max_width":"1230","main_full_width":"no","main_space":{"top":"70","bottom":"30"},"google_rich_snippets":"no","backtotop_btn":"no","body_background":{"image":"","repeat":"repeat","position":"left top","attachment":"","size":"","color":""},"body_boxed_background":{"image":"","repeat":"repeat","position":"left top","attachment":"","size":"","color":""},"text_color":"#b8b8b8","heading_color":"#272727","primary_color":"#af5875","secondary_color":"#272727","three_color":"#b8b8b8","border_color":"#ebebeb","page_loading_animation":"on","page_loading_style":"2","page_loading_custom":"","body_font_size":"12px","font_source":"1","main_font":{"family":"Montserrat","variant":["regular"],"font":"google"},"secondary_font":{"family":"Montserrat","variant":["regular","700"],"font":"google"},"highlight_font":{"family":"Playfair Display","variant":["regular","italic"],"font":"google"},"font_google_code":"","main_google_font_face":"","secondary_google_font_face":"","highlight_google_font_face":"","font_typekit_kit_id":"","main_typekit_font_face":"","secondary_typekit_font_face":"","highlight_typekit_font_face":"","heading_custom_font":"no","header_layout":"1","header_full_width":"no","header_transparency":"no","header_show_cart":"yes","header_show_search":"yes","header_show_wishlist":"yes","header_top_menu_language":"15","header_top_menu_access":"16","header_top_social":"yes","use_custom_header_top":"","header_background":{"image":"","repeat":"repeat","position":"left top","attachment":"","size":"","color":"#fff"},"header_text_color":"#272727","header_link_color":"#272727","header_link_hover_color":"#af5875","mm_lv_1_color":"#272727","mm_lv_1_bg_color":"rgba(0,0,0,0)","mm_lv_1_hover_color":"#af5875","mm_lv_1_hover_bg_color":"rgba(0,0,0,0)","header_top_background_color":"rgba(0,0,0,0)","header_top_text_color":"#272727","header_top_link_color":"#272727","header_top_link_hover_color":"#af5875","transparency_header_background":{"image":"","repeat":"repeat","position":"left top","attachment":"","size":"","color":"rgba(0,0,0,0)"},"transparency_header_text_color":"#fff","transparency_header_link_color":"#fff","transparency_header_link_hover_color":"#af5875","transparency_mm_lv_1_color":"#fff","transparency_mm_lv_1_bg_color":"rgba(0,0,0,0)","transparency_mm_lv_1_hover_color":"#af5875","transparency_mm_lv_1_hover_bg_color":"rgba(0,0,0,0)","transparency_header_top_background_color":"rgba(0,0,0,0)","transparency_header_top_text_color":"#ffffff","transparency_header_top_link_color":"#ffffff","transparency_header_top_link_hover_color":"#af5875","offcanvas_background":"#fff","offcanvas_text_color":"#272727","offcanvas_heading_color":"#272727","offcanvas_link_color":"#272727","offcanvas_link_hover_color":"#af5875","mm_dropdown_bg":"#272727","mm_dropdown_link_color":"#858585","mm_dropdown_link_bg":"rgba(0,0,0,0)","mm_dropdown_link_hover_color":"#ffffff","mm_dropdown_link_hover_bg":"rgba(0,0,0,0)","mm_wide_dropdown_bg":"#272727","mm_wide_dropdown_heading_color":"#ffffff","mm_wide_dropdown_link_color":"#858585","mm_wide_dropdown_link_bg":"rgba(0,0,0,0)","mm_wide_dropdown_link_hover_color":"#ffffff","mm_wide_dropdown_link_hover_bg":"rgba(0,0,0,0)","header_mb_background":"#fff","header_mb_text_color":"#b8b8b8","mb_background":"#fff","mb_lv_1_color":"#272727","mb_lv_1_bg_color":"rgba(0,0,0,0)","mb_lv_1_hover_color":"#af5875","mb_lv_1_hover_bg_color":"rgba(0,0,0,0)","mb_lv_2_color":"#272727","mb_lv_2_bg_color":"rgba(0,0,0,0)","mb_lv_2_hover_color":"#fff","mb_lv_2_hover_bg_color":"#af5875","page_title_bar_layout":"1","page_title_bar_background":{"image":"","repeat":"repeat","position":"left top","attachment":"","size":"","color":""},"page_title_bar_heading_color":"#272727","page_title_bar_text_color":"#b8b8b8","page_title_bar_link_color":"#b8b8b8","page_title_bar_link_hover_color":"#af5875","page_title_bar_spacing":{"top":"35","bottom":"35"},"page_title_bar_spacing_tablet":{"top":"25","bottom":"25"},"page_title_bar_spacing_mobile":{"top":"25","bottom":"25"},"woo_override_page_title_bar":"off","woo_page_title_bar_layout":"1","woo_page_title_bar_background":{"image":"","repeat":"repeat","position":"left top","attachment":"","size":"","color":""},"woo_page_title_bar_heading_color":"","woo_page_title_bar_text_color":"#9d9d9d","woo_page_title_bar_link_color":"#9d9d9d","woo_page_title_bar_link_hover_color":"#35d56a","woo_page_title_bar_spacing":{"top":"40","bottom":"40"},"woo_page_title_bar_spacing_tablet":{"top":"25","bottom":"25"},"woo_page_title_bar_spacing_mobile":{"top":"25","bottom":"25"},"pages_sidebar":"","portfolio_sidebar":"","portfolio_archive_sidebar":"","posts_sidebar":"","blog_archive_sidebar":"","search_sidebar":"","products_sidebar":"","shop_sidebar":"","footer_layout":"4col123333","footer_full_width":"no","enable_footer_copyright":"yes","footer_background":{"image":"","repeat":"repeat","position":"left top","attachment":"","size":"","color":"#272727"},"footer_text_color":"#616161","footer_heading_color":"#ffffff","footer_link_color":"#616161","footer_link_hover_color":"#af5875","footer_copyright_background_color":"#272727","footer_copyright_text_color":"#7b7b7b","footer_copyright_link_color":"#af5875","footer_copyright_link_hover_color":"#fff","layout_blog":"col-2cl","blog_small_layout":"off","page_title_bar_layout_blog":"inherit","blog_design":"grid_4","blog_post_column":{"xlg":"1","lg":"1","md":"1","sm":"1","xs":"1","mb":"1"},"featured_images_blog":"on","blog_thumbnail_size2":"full","blog_thumbnail_size":"full","format_content_blog":"off","blog_content_display":"excerpt","blog_excerpt_length":"100","blog_masonry":"off","blog_pagination_type":"pagination","layout_single_post":"col-1c","single_small_layout":"off","page_title_bar_layout_single":"off","featured_images_single":"on","blog_pn_nav":"on","blog_post_title":"below","blog_author_info":"on","blog_social_sharing_box":"on","blog_related_posts":"off","blog_related_design":"1","blog_related_by":"category","blog_related_max_post":"2","blog_comments":"on","layout_archive_product":"col-1c","catalog_mode":"off","catalog_mode_price":"off","shop_catalog_display_type":"grid","shop_catalog_grid_style":"1","woocommerce_shop_page_columns":{"xlg":"4","lg":"4","md":"3","sm":"2","xs":"2","mb":"1"},"product_per_page_allow":"12,15,30","product_per_page_default":"12","woocommerce_enable_crossfade_effect":"on","woocommerce_toggle_grid_list":"on","woocommerce_show_rating_on_catalog":"on","woocommerce_show_quickview_btn":"on","woocommerce_show_wishlist_btn":"on","woocommerce_show_compare_btn":"on","layout_single_product":"col-1c","woocommerce_product_page_design":"2","product_sharing":"on","related_products":"on","related_products_columns":{"xlg":"4","lg":"4","md":"3","sm":"2","xs":"2","mb":"1"},"upsell_products":"on","upsell_products_columns":{"xlg":"4","lg":"4","md":"3","sm":"2","xs":"2","mb":"1"},"crosssell_products":"on","crosssell_products_columns":{"xlg":"4","lg":"4","md":"3","sm":"2","xs":"1","mb":"1"},"layout_archive_portfolio":"col-1c","main_full_width_archive_portfolio":"inherit","main_space_archive_portfolio":{"top":"","bottom":""},"portfolio_display_type":"grid","portfolio_item_space":"0","portfolio_display_style":"1","portfolio_column":{"xlg":"3","lg":"3","md":"2","sm":"2","xs":"1","mb":"1"},"portfolio_per_page":"6","portfolio_thumbnail_size":"370x300","layout_single_portfolio":"col-1c","single_portfolio_design":"1","single_portfolio_nextprev":"on","social_links":{"1":{"title":"Facebook","icon":"fa fa-facebook","link":"#"},"2":{"title":"Twitter","icon":"fa fa-twitter","link":"#"},"3":{"title":"Pinterest","icon":"fa fa-pinterest-p","link":"#"}},"sharing_facebook":true,"sharing_twitter":true,"sharing_google_plus":true,"sharing_pinterest":true,"google_key":"AIzaSyCRVgKaDYPQokbMuy5fvGy-QoR44WNG7IA","instagram_token":"4056544068.d1a3d85.9d2eba44616b4f4c9ec2e4a9c6d89d27","la_custom_css":"","header_js":"","footer_js":"","popup_background":{"image":"","repeat":"repeat","position":"left top","attachment":"","size":"","color":""},"newsletter_popup_delay":"2000","show_checkbox_hide_newsletter_popup":true,"popup_dont_show_text":"Do not show popup anymore","newsletter_popup_show_again":"1","newsletter_popup_content":"","enable_maintenance":"yes","maintenance_page":"","import":"","add_sidebars":"","pages_global_sidebar":false,"portfolio_global_sidebar":false,"portfolio_archive_global_sidebar":false,"posts_global_sidebar":false,"blog_archive_global_sidebar":false,"products_global_sidebar":false,"shop_global_sidebar":false,"sharing_reddit":false,"sharing_linkedin":false,"sharing_tumblr":false,"sharing_vk":false,"sharing_email":false,"enable_newsletter_popup":false,"only_show_newsletter_popup_on_home_page":false,"disable_popup_on_mobile":false}',true)
            );
        }
        remove_image_size('yith-woocompare-image');
        add_editor_style( 'editor-style.css' );
    }

    public function widget_init(){
        register_widget('Sebian_Widget_Contact_Info');
        register_widget('Sebian_Widget_Twitter_Feed');
        register_sidebar(array(
            'name'          => esc_attr__( 'Sidebar Widget Area', 'sebian' ),
            'id'            => 'sidebar-primary',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>'
        ));
        register_sidebar(array(
            'name'          => esc_attr__( 'Sidebar Shop Filter', 'sebian' ),
            'id'            => 'sidebar-shop-filter',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>'
        ));
        register_sidebar(array(
            'name'          => esc_attr__( 'Aside Header Widget Area', 'sebian' ),
            'id'            => 'aside-widget',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="widget-title"><span>',
            'after_title'   => '</span></h4>'
        ));
        register_sidebar( array(
            'name'          => esc_attr__( 'Footer Top Widget Area', 'sebian' ),
            'id'            => 'f-col-top',
            'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-inner">',
            'after_widget'  => '</div></div>',
            'before_title'  => '<h4 class="h3 widget-title"><span>',
            'after_title'   => '</span></h4>'
        ) );
        register_sidebar( array(
            'name'          => esc_attr__( 'Footer Widget Area Column 1', 'sebian' ),
            'id'            => 'f-col-1',
            'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-inner">',
            'after_widget'  => '</div></div>',
            'before_title'  => '<h4 class="h3 widget-title"><span>',
            'after_title'   => '</span></h4>'
        ) );
        register_sidebar( array(
            'name'          => esc_attr__( 'Footer Widget Area Column 2', 'sebian' ),
            'id'            => 'f-col-2',
            'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-inner">',
            'after_widget'  => '</div></div>',
            'before_title'  => '<h4 class="h3 widget-title"><span>',
            'after_title'   => '</span></h4>'
        ) );
        register_sidebar( array(
            'name'          => esc_attr__( 'Footer Widget Area Column 3', 'sebian' ),
            'id'            => 'f-col-3',
            'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-inner">',
            'after_widget'  => '</div></div>',
            'before_title'  => '<h4 class="h3 widget-title"><span>',
            'after_title'   => '</span></h4>',
        ) );
        register_sidebar( array(
            'name'          => esc_attr__( 'Footer Widget Area Column 4', 'sebian' ),
            'id'            => 'f-col-4',
            'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-inner">',
            'after_widget'  => '</div></div>',
            'before_title'  => '<h4 class="h3 widget-title"><span>',
            'after_title'   => '</span></h4>'
        ) );
        register_sidebar(array(
            'name'          => esc_attr__( 'Custom Block Top', 'sebian' ),
            'id'            => 'la-custom-block-top',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="h3 widget-title"><span>',
            'after_title'   => '</span></h4>'
        ));
        register_sidebar(array(
            'name'          => esc_attr__( 'Custom Block Inner Top', 'sebian' ),
            'id'            => 'la-custom-block-inner-top',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="h3 widget-title"><span>',
            'after_title'   => '</span></h4>'
        ));
        register_sidebar(array(
            'name'          => esc_attr__( 'Custom Block Inner Bottom', 'sebian' ),
            'id'            => 'la-custom-block-inner-bottom',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="h3 widget-title"><span>',
            'after_title'   => '</span></h4>'
        ));
        register_sidebar(array(
            'name'          => esc_attr__( 'Custom Block Bottom', 'sebian' ),
            'id'            => 'la-custom-block-bottom',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="h3 widget-title"><span>',
            'after_title'   => '</span></h4>'
        ));
        
        $dynamic_sidebar = Sebian()->settings->get('add_sidebars');
        if(!empty($dynamic_sidebar)){
            foreach($dynamic_sidebar as $sidebar){
                if(empty($sidebar['sidebar_id'])){
                    continue;
                }
                register_sidebar(array(
                    'name'          => esc_html($sidebar['sidebar_id']),
                    'id'            => sanitize_title($sidebar['sidebar_id']),
                    'description'   => sprintf(__('ID:{{%s}} ', 'sebian'), sanitize_title($sidebar['sidebar_id'])) . (!empty($sidebar['sidebar_desc']) ? esc_html($sidebar['sidebar_desc']) : ''),
                    'before_widget' => '<div id="%1$s" class="widget %2$s">',
                    'after_widget'  => '</div>',
                    'before_title'  => '<h4 class="h3 widget-title"><span>',
                    'after_title'   => '</span></h4>',
                ));
            }
        }
    }

    public function modify_contact_methods( $profile_fields ) {
        // Add new fields.
        $profile_fields['author_custom']   = esc_html__('Custom Message (Author Page)', 'sebian');
        $profile_fields['author_facebook'] = esc_html__('Facebook (Author Page)', 'sebian');
        $profile_fields['author_twitter']  = esc_html__('Twitter (Author Page)','sebian');
        $profile_fields['author_pinterest']  = esc_html__('Pinterest (Author Page)','sebian');
        $profile_fields['author_linkedin'] = esc_html__('LinkedIn (Author Page)','sebian');
        $profile_fields['author_gplus']    = esc_html__('Google+ (Author Page)','sebian');
        $profile_fields['author_dribble']  = esc_html__('Dribble (Author Page)','sebian');

        return $profile_fields;
    }

}