<?php

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
    exit( 'Direct script access denied.' );
}


/**
 * General settings
 *
 * @param array $sections An array of our sections.
 * @return array
 */
function sebian_options_section_general( $sections ) {
    $sections['general'] = array(
        'name'          => 'general_panel',
        'title'         => esc_html__('General', 'sebian'),
        'icon'          => 'fa fa-tachometer',
        'sections' => array(
            array(
                'name'      => 'general_sections',
                'title'     => esc_html__('General', 'sebian'),
                'icon'      => 'fa fa-check',
                'fields'    => array(
                    array(
                        'id'        => 'layout',
                        'title'     => esc_html__('Global Layout', 'sebian'),
                        'type'      => 'image_select',
                        'radio'     => true,
                        'default'   => 'col-1c',
                        'desc'      => esc_html__('Select main content and sidebar alignment. Choose between 1, 2 or 3 column layout.', 'sebian'),
                        'options'   => Sebian_Options::get_config_main_layout_opts(true, false)
                    ),
                    array(
                        'id'        => 'body_boxed',
                        'type'      => 'radio',
                        'default'   => 'no',
                        'class'     => 'la-radio-style',
                        'title'     => esc_html__('Enable Layout Boxed', 'sebian'),
                        'options'   => Sebian_Options::get_config_radio_opts(false)
                    ),
                    array(
                        'id'        => 'body_max_width',
                        'type'      => 'slider',
                        'default'    => 1230,
                        'title'     => esc_html__( 'Body Max Width', 'sebian' ),
                        'dependency' => array('body_boxed_yes', '==', 'true'),
                        'options'   => array(
                            'step'    => 5,
                            'min'     => 900,
                            'max'     => 2000,
                            'unit'    => 'px'
                        )
                    ),
                    array(
                        'id'        => 'main_full_width',
                        'type'      => 'radio',
                        'default'   => 'no',
                        'class'     => 'la-radio-style',
                        'title'     => esc_html__('100% Main Width', 'sebian'),
                        'desc'      => esc_html__('Turn on to have the main area display at 100% width according to the window size. Turn off to follow site width.', 'sebian'),
                        'options'   => Sebian_Options::get_config_radio_opts(false)
                    ),
                    array(
                        'id'            => 'main_space',
                        'type'          => 'spacing',
                        'title'         => esc_html__('Custom Main Space', 'sebian'),
                        'desc'          => esc_html__('Leave empty if you not need', 'sebian'),
                        'unit' 	        => 'px',
                        'default'       => array(
                            'top'       => '70',
                            'bottom'    => '30'
                        )
                    ),
                    array(
                        'id'        => 'google_rich_snippets',
                        'type'      => 'radio',
                        'default'   => 'no',
                        'class'     => 'la-radio-style',
                        'title'     => esc_html__('Breadcrumbs Google Rich Snippets', 'sebian'),
                        'desc'      => esc_html__('Turn on to the Google Rich Snippets in the Breadcrumbs.', 'sebian'),
                        'options'   => Sebian_Options::get_config_radio_opts(false)
                    ),
                    array(
                        'id'        => 'backtotop_btn',
                        'type'      => 'radio',
                        'default'   => 'no',
                        'class'     => 'la-radio-style',
                        'title'     => esc_html__('"Back to top" Button', 'sebian'),
                        'desc'      => esc_html__('Turn on to show "Back to top" button', 'sebian'),
                        'options'   => Sebian_Options::get_config_radio_opts(false)
                    )
                )
            ),
            array(
                'name'      => 'favicon_sections',
                'title'     => esc_html__('Custom Favicon', 'sebian'),
                'icon'      => 'fa fa-check',
                'fields'    => array(
                    array(
                        'id'        => 'favicon',
                        'type'      => 'image',
                        'title'     => esc_html__('Favicon', 'sebian'),
                        'desc'      => esc_html__('Favicon for your website at 16px x 16px.', 'sebian')
                    ),
                    array(
                        'id'        => 'favicon_iphone',
                        'type'      => 'image',
                        'title'     => esc_html__('Apple iPhone Icon Upload', 'sebian'),
                        'desc'      => esc_html__('Favicon for Apple iPhone at 57px x 57px.', 'sebian')
                    ),
                    array(
                        'id'        => 'favicon_ipad',
                        'type'      => 'image',
                        'title'     => esc_html__('Apple iPad Icon Upload', 'sebian'),
                        'desc'      => esc_html__('Favicon for Apple iPad at 72px x 72px.', 'sebian')
                    )
                )
            ),
            array(
                'name'      => 'logo_sections',
                'title'     => esc_html__('Logo', 'sebian'),
                'icon'      => 'fa fa-check',
                'fields'    => array(
                    array(
                        'id'        => 'logo',
                        'type'      => 'image',
                        'title'     => esc_html__('Default Logo', 'sebian'),
                        'desc'      => esc_html__('Select an image file for your logo.', 'sebian')
                    ),
                    array(
                        'id'        => 'logo_2x',
                        'type'      => 'image',
                        'title'     => esc_html__('Retina Default Logo', 'sebian'),
                        'desc'      => esc_html__('Select an image file for the retina version of the logo. It should be exactly 2x the size of the main logo.', 'sebian')
                    ),
                    array(
                        'id'        => 'logo_transparency',
                        'type'      => 'image',
                        'title'     => esc_html__('Transparency Header Logo', 'sebian'),
                        'desc'      => esc_html__('Select an image file for your transparency header logo.', 'sebian')
                    ),
                    array(
                        'id'        => 'logo_transparency_2x',
                        'type'      => 'image',
                        'title'     => esc_html__('Retina Transparency Logo', 'sebian'),
                        'desc'      => esc_html__('Select an image file for the retina version of the logo. It should be exactly 2x the size of the transparency header logo.', 'sebian')
                    ),
                    array(
                        'id'        => 'logo_mobile',
                        'type'      => 'image',
                        'title'     => esc_html__('Mobile Logo', 'sebian'),
                        'desc'      => esc_html__('Select an image file for your mobile logo.', 'sebian')
                    ),
                    array(
                        'id'        => 'logo_mobile_2x',
                        'type'      => 'image',
                        'title'     => esc_html__('Retina Mobile Logo', 'sebian'),
                        'desc'      => esc_html__('Select an image file for the retina version of the logo. It should be exactly 2x the size of the mobile logo.', 'sebian')
                    )
                )
            ),
            array(
                'name'      => 'color_sections',
                'title'     => esc_html__('Colors', 'sebian'),
                'icon'      => 'fa fa-paint-brush',
                'fields'    => array(
                    array(
                        'id'        => 'body_background',
                        'type'      => 'background',
                        'title'     => esc_html__('Body Background', 'sebian')
                    ),
                    array(
                        'id'        => 'body_boxed_background',
                        'type'      => 'background',
                        'title'     => esc_html__('Body Boxed Background', 'sebian'),
                        'dependency' => array('body_boxed_yes', '==', 'true'),
                    ),
                    array(
                        'id'        => 'text_color',
                        'default'   => Sebian_Options::get_color_default('text_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Text Color', 'sebian')
                    ),
                    array(
                        'id'        => 'heading_color',
                        'default'   => Sebian_Options::get_color_default('heading_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Heading Color', 'sebian')
                    ),
                    array(
                        'id'        => 'primary_color',
                        'default'   => Sebian_Options::get_color_default('primary_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Primary Color', 'sebian')
                    ),
                    array(
                        'id'        => 'secondary_color',
                        'default'   => Sebian_Options::get_color_default('secondary_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Secondary Color', 'sebian')
                    ),
                    array(
                        'id'        => 'three_color',
                        'default'   => Sebian_Options::get_color_default('three_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Three Color', 'sebian')
                    ),
                    array(
                        'id'        => 'border_color',
                        'default'   => Sebian_Options::get_color_default('border_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Border Color', 'sebian')
                    )
                )
            ),
            array(
                'name'      => 'loading_sections',
                'title'     => esc_html__('Page Loading', 'sebian'),
                'icon'      => 'fa fa-refresh fa-spin',
                'fields'    => array(
                    array(
                        'id'        => 'page_loading_animation',
                        'type'      => 'radio',
                        'class'     => 'la-radio-style',
                        'default'   => 'off',
                        'title'     => esc_html__('Page Loading Animation', 'sebian'),
                        'desc'      => esc_html__('Turn on to show the icon/images loading animation before view site', 'sebian'),
                        'options'   => Sebian_Options::get_config_radio_onoff(false)
                    ),
                    array(
                        'id'        => 'page_loading_style',
                        'type'      => 'select',
                        'default'   => '1',
                        'title'     => esc_html__('Page Loading Style', 'sebian'),
                        'options'   => array(
                            '1'         => esc_html__('Style 1', 'sebian'),
                            '2'         => esc_html__('Style 2', 'sebian'),
                            '3'         => esc_html__('Style 3', 'sebian'),
                            '4'         => esc_html__('Style 4', 'sebian'),
                            'custom'    => esc_html__('Custom image', 'sebian')
                        ),
                        'dependency' => array('page_loading_animation_on', '==', 'true'),
                    ),
                    array(
                        'id'        => 'page_loading_custom',
                        'type'      => 'image',
                        'title'     => esc_html__('Custom Page Loading Image', 'sebian'),
                        'add_title' => esc_html__('Add Image', 'sebian'),
                        'dependency'=> array('page_loading_animation_on|page_loading_style', '==|==', 'true|custom'),
                    )
                )
            )
        )
    );
    return $sections;
}