<?php

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
    exit( 'Direct script access denied.' );
}


/**
 * Header settings
 *
 * @param array $sections An array of our sections.
 * @return array
 */
function sebian_options_section_header( $sections ) {
    $sections['header'] = array(
        'name'          => 'header_panel',
        'title'         => esc_html__('Header', 'sebian'),
        'icon'          => 'fa fa-arrow-up',
        'sections' => array(
            array(
                'name'      => 'header_layout_sections',
                'title'     => esc_html__('Layout', 'sebian'),
                'icon'      => 'fa fa-cog',
                'fields'    => array(
                    array(
                        'id'        => 'header_layout',
                        'title'     => esc_html__('Header Layout', 'sebian'),
                        'type'      => 'image_select',
                        'radio'     => true,
                        'class'     => 'la-radio-style',
                        'default'   => '1',
                        'desc'      => esc_html__('Controls the general layout of the header.', 'sebian'),
                        'options'   => Sebian_Options::get_config_header_layout_opts(true, false)
                    ),
                    array(
                        'id'        => 'header_full_width',
                        'type'      => 'radio',
                        'default'   => 'no',
                        'class'     => 'la-radio-style',
                        'title'     => esc_html__('100% Header Width', 'sebian'),
                        'desc'      => esc_html__('Turn on to have the header area display at 100% width according to the window size. Turn off to follow site width.', 'sebian'),
                        'options'   => Sebian_Options::get_config_radio_opts(false),
                        'info'      => esc_html__('This option do not allow for header type 4,5', 'sebian')
                    ),
                    array(
                        'id'        => 'header_transparency',
                        'type'      => 'radio',
                        'default'   => 'no',
                        'class'     => 'la-radio-style',
                        'title'     => esc_html__('Header Transparency', 'sebian'),
                        'options'   => Sebian_Options::get_config_radio_opts(false),
                        'info'      => esc_html__('This option do not allow for header type 4,5', 'sebian')
                    )
                )
            ),
            array(
                'name'      => 'header_element_sections',
                'title'     => esc_html__('Elements', 'sebian'),
                'icon'      => 'fa fa-cog',
                'fields'    => array(
                    array(
                        'id'        => 'header_show_cart',
                        'type'      => 'radio',
                        'default'   => 'no',
                        'class'     => 'la-radio-style',
                        'title'     => esc_html__('Header Shopping Cart', 'sebian'),
                        'desc'      => esc_html__('Show/Hide Shopping Cart in the Header.', 'sebian'),
                        'options'   => Sebian_Options::get_config_radio_opts(false)
                    ),
                    array(
                        'id'        => 'header_show_search',
                        'type'      => 'radio',
                        'default'   => 'no',
                        'class'     => 'la-radio-style',
                        'title'     => esc_html__('Header Search Form', 'sebian'),
                        'desc'      => esc_html__('Show/Hide Search Form in the Header.', 'sebian'),
                        'options'   => Sebian_Options::get_config_radio_opts(false)
                    ),
                    array(
                        'id'        => 'header_show_wishlist',
                        'type'      => 'radio',
                        'default'   => 'no',
                        'class'     => 'la-radio-style',
                        'title'     => esc_html__('Header Wishlist Icon', 'sebian'),
                        'desc'      => esc_html__('Show/Hide Wishlist Icon in the Header.', 'sebian'),
                        'options'   => Sebian_Options::get_config_radio_opts(false)
                    ),
                    array(
                        'id'        => 'enable_header_top',
                        'type'      => 'radio',
                        'default'   => 'no',
                        'class'     => 'la-radio-style',
                        'title'     => esc_html__('Enable Header Top Area?', 'sebian'),
                        'desc'      => esc_html__('Show/Hide Header Top Area in the Header.', 'sebian'),
                        'options'   => array(
                            'no'            => esc_html__('Hide', 'sebian'),
                            'yes'           => esc_html__('Show', 'sebian'),
                            'custom'        => esc_html__('Use Custom HTML', 'sebian')
                        )
                    ),
                    array(
                        'id'            => 'header_top_menu_language',
                        'type'          => 'select',
                        'title'         => esc_html__('Select Language Menu','sebian'),
                        'class'         => 'chosen',
                        'options'       => 'tags',
                        'query_args'    => array(
                            'orderby'   => 'name',
                            'order'     => 'ASC',
                            'taxonomies'=>  'nav_menu'
                        ),
                        'default_option'=> esc_html__('Select a Menu', 'sebian'),
                        'dependency'    => array('enable_header_top_yes', '==', true)
                    ),
                    array(
                        'id'            => 'header_top_menu_access',
                        'type'          => 'select',
                        'title'         => esc_html__('Select Quicklinks Menu','sebian'),
                        'class'         => 'chosen',
                        'options'       => 'tags',
                        'query_args'    => array(
                            'orderby'   => 'name',
                            'order'     => 'ASC',
                            'taxonomies'=>  'nav_menu'
                        ),
                        'default_option'=> esc_html__('Select a Menu', 'sebian'),
                        'dependency'    => array('enable_header_top_yes', '==', true)
                    ),
                    array(
                        'id'        => 'header_top_social',
                        'type'      => 'radio',
                        'default'   => 'yes',
                        'class'     => 'la-radio-style',
                        'title'     => esc_html__('Header Top Social', 'sebian'),
                        'desc'      => esc_html__('Show/Hide Social Icon in the Header.', 'sebian'),
                        'options'   => Sebian_Options::get_config_radio_opts(false),
                        'dependency'    => array('enable_header_top_yes', '==', true)
                    ),
                    array(
                        'id'        => 'use_custom_header_top',
                        'type'      => 'ace_editor',
                        'mode'      => 'html',
                        'title'     => esc_html__('Custom HTML For Header Top', 'sebian'),
                        'desc'      => esc_html__('Paste your custom HTML code here.', 'sebian'),
                        'dependency'    => array('enable_header_top_custom', '==', true)
                    )
                )
            ),
            array(
                'name'      => 'header_default_styling_sections',
                'title'     => esc_html__('Default Header Styling', 'sebian'),
                'icon'      => 'fa fa-paint-brush',
                'fields'    => array(
                    array(
                        'id'        => 'header_background',
                        'type'      => 'background',
                        'default'       => array(
                            'color' => '#fff'
                        ),
                        'title'     => esc_html__('Background', 'sebian'),
                        'desc'      => esc_html__('for default header', 'sebian'),
                    ),
                    array(
                        'id'        => 'header_text_color',
                        'type'      => 'color_picker',
                        'default'   => Sebian_Options::get_color_default('secondary_color'),
                        'title'     => esc_html__('Text Color', 'sebian'),
                        'desc'      => esc_html__('For default header', 'sebian'),
                    ),
                    array(
                        'id'        => 'header_link_color',
                        'type'      => 'color_picker',
                        'default'   => Sebian_Options::get_color_default('secondary_color'),
                        'title'     => esc_html__('Link Color', 'sebian'),
                        'desc'      => esc_html__('For default header', 'sebian'),
                    ),
                    array(
                        'id'        => 'header_link_hover_color',
                        'type'      => 'color_picker',
                        'default'   => Sebian_Options::get_color_default('primary_color'),
                        'title'     => esc_html__('Link Hover Color', 'sebian'),
                        'desc'      => esc_html__('For default header', 'sebian'),
                    ),
                    array(
                        'id'        => 'mm_lv_1_color',
                        'type'      => 'color_picker',
                        'default'   => Sebian_Options::get_color_default('secondary_color'),
                        'title'     => esc_html__('Menu Level 1 Color', 'sebian'),
                        'desc'      => esc_html__('For default header', 'sebian'),
                    ),
                    array(
                        'id'        => 'mm_lv_1_bg_color',
                        'type'      => 'color_picker',
                        'default'   => 'rgba(0,0,0,0)',
                        'title'     => esc_html__('Menu Level 1 Background Color', 'sebian'),
                        'desc'      => esc_html__('For default header', 'sebian')
                    ),
                    array(
                        'id'        => 'mm_lv_1_hover_color',
                        'type'      => 'color_picker',
                        'default'   => Sebian_Options::get_color_default('primary_color'),
                        'title'     => esc_html__('Menu Level 1 Hover Color', 'sebian'),
                        'desc'      => esc_html__('For default header', 'sebian')
                    ),
                    array(
                        'id'        => 'mm_lv_1_hover_bg_color',
                        'type'      => 'color_picker',
                        'default'   => 'rgba(0,0,0,0)',
                        'title'     => esc_html__('Menu Level 1 Hover Background Color', 'sebian'),
                        'desc'      => esc_html__('For default header', 'sebian')
                    ),
                    array(
                        'type'    => 'notice',
                        'class'   => 'no-format la-section-title',
                        'content' => sprintf('<h3>%s</h3>', esc_html__('Header Top Styling', 'sebian'))
                    ),
                    array(
                        'id'        => 'header_top_background_color',
                        'type'      => 'color_picker',
                        'default'   => 'rgba(0,0,0,0)',
                        'title'     => esc_html__('Header Top Background Color', 'sebian'),
                        'desc'      => esc_html__('For default header top', 'sebian'),
                    ),
                    array(
                        'id'        => 'header_top_text_color',
                        'type'      => 'color_picker',
                        'default'   => 'rgba(255,255,255,0.2)',
                        'title'     => esc_html__('Header Top Text Color', 'sebian'),
                        'desc'      => esc_html__('For default header top', 'sebian'),
                    ),
                    array(
                        'id'        => 'header_top_link_color',
                        'type'      => 'color_picker',
                        'default'   => '#fff',
                        'title'     => esc_html__('Header Top Link Color', 'sebian'),
                        'desc'      => esc_html__('For default header top', 'sebian'),
                    ),
                    array(
                        'id'        => 'header_top_link_hover_color',
                        'type'      => 'color_picker',
                        'default'   => Sebian_Options::get_color_default('primary_color'),
                        'title'     => esc_html__('Header Top Link Hover Color', 'sebian'),
                        'desc'      => esc_html__('For default header top', 'sebian'),
                    )
                )
            ),
            array(
                'name'      => 'header_transparency_styling_sections',
                'title'     => esc_html__('Transparency Header Styling', 'sebian'),
                'icon'      => 'fa fa-paint-brush',
                'fields'    => array(
                    array(
                        'id'        => 'transparency_header_background',
                        'type'      => 'background',
                        'default'       => array(
                            'color' => 'rgba(0,0,0,0)'
                        ),
                        'title'     => esc_html__('Background', 'sebian'),
                        'desc'      => esc_html__('For transparency header', 'sebian')
                    ),
                    array(
                        'id'        => 'transparency_header_text_color',
                        'type'      => 'color_picker',
                        'default'   => '#fff',
                        'title'     => esc_html__('Text Color', 'sebian'),
                        'desc'      => esc_html__('For transparency header', 'sebian')
                    ),
                    array(
                        'id'        => 'transparency_header_link_color',
                        'type'      => 'color_picker',
                        'default'   => '#fff',
                        'title'     => esc_html__('Link Color', 'sebian'),
                        'desc'      => esc_html__('For transparency header', 'sebian')
                    ),
                    array(
                        'id'        => 'transparency_header_link_hover_color',
                        'type'      => 'color_picker',
                        'default'   => Sebian_Options::get_color_default('primary_color'),
                        'title'     => esc_html__('Link Hover Color', 'sebian'),
                        'desc'      => esc_html__('For transparency header', 'sebian')
                    ),
                    array(
                        'id'        => 'transparency_mm_lv_1_color',
                        'type'      => 'color_picker',
                        'default'   => '#fff',
                        'title'     => esc_html__('Menu Level 1 Color', 'sebian'),
                        'desc'      => esc_html__('For transparency header', 'sebian')
                    ),
                    array(
                        'id'        => 'transparency_mm_lv_1_bg_color',
                        'type'      => 'color_picker',
                        'default'   => 'rgba(0,0,0,0)',
                        'title'     => esc_html__('Menu Level 1 Background Color', 'sebian'),
                        'desc'      => esc_html__('For transparency header', 'sebian')
                    ),
                    array(
                        'id'        => 'transparency_mm_lv_1_hover_color',
                        'type'      => 'color_picker',
                        'default'   => Sebian_Options::get_color_default('primary_color'),
                        'title'     => esc_html__('Menu Level 1 Hover Color', 'sebian'),
                        'desc'      => esc_html__('For transparency header', 'sebian')
                    ),
                    array(
                        'id'        => 'transparency_mm_lv_1_hover_bg_color',
                        'type'      => 'color_picker',
                        'default'   => 'rgba(0,0,0,0)',
                        'title'     => esc_html__('Menu Level 1 Hover Background Color', 'sebian'),
                        'desc'      => esc_html__('For transparency header', 'sebian')
                    ),
                    array(
                        'type'    => 'notice',
                        'class'   => 'no-format la-section-title',
                        'content' => sprintf('<h3>%s</h3>', esc_html__('Transparency Header Top Styling', 'sebian'))
                    ),
                    array(
                        'id'        => 'transparency_header_top_background_color',
                        'type'      => 'color_picker',
                        'default'   => 'rgba(0,0,0,0)',
                        'title'     => esc_html__('Header Top Background Color', 'sebian'),
                        'desc'      => esc_html__('For transparency header top', 'sebian'),
                    ),
                    array(
                        'id'        => 'transparency_header_top_text_color',
                        'type'      => 'color_picker',
                        'default'   => 'rgba(255,255,255,0.2)',
                        'title'     => esc_html__('Header Top Text Color', 'sebian'),
                        'desc'      => esc_html__('For transparency header top', 'sebian'),
                    ),
                    array(
                        'id'        => 'transparency_header_top_link_color',
                        'type'      => 'color_picker',
                        'default'   => '#fff',
                        'title'     => esc_html__('Header Top Link Color', 'sebian'),
                        'desc'      => esc_html__('For transparency header top', 'sebian'),
                    ),
                    array(
                        'id'        => 'transparency_header_top_link_hover_color',
                        'type'      => 'color_picker',
                        'default'   => Sebian_Options::get_color_default('primary_color'),
                        'title'     => esc_html__('Header Top Link Hover Color', 'sebian'),
                        'desc'      => esc_html__('For transparency header top', 'sebian'),
                    )
                )
            ),
            array(
                'name'      => 'header_offcanvas_styling_sections',
                'title'     => esc_html__('Aside Menu Styling', 'sebian'),
                'icon'      => 'fa fa-paint-brush',
                'fields'    => array(
                    array(
                        'id'        => 'offcanvas_background',
                        'default'   => '#fff',
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Background Color', 'sebian'),
                        'desc'      => esc_html__('For Aside Header', 'sebian')
                    ),
                    array(
                        'id'        => 'offcanvas_text_color',
                        'default'   => Sebian_Options::get_color_default('secondary_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Text color', 'sebian'),
                        'desc'      => esc_html__('For Aside Header', 'sebian')
                    ),
                    array(
                        'id'        => 'offcanvas_heading_color',
                        'default'   => Sebian_Options::get_color_default('heading_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Heading color', 'sebian'),
                        'desc'      => esc_html__('For Aside Header', 'sebian')
                    ),
                    array(
                        'id'        => 'offcanvas_link_color',
                        'default'   => Sebian_Options::get_color_default('secondary_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Link color', 'sebian'),
                        'desc'      => esc_html__('For Aside Header', 'sebian')
                    ),
                    array(
                        'id'        => 'offcanvas_link_hover_color',
                        'default'   => Sebian_Options::get_color_default('primary_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Link Hover color', 'sebian'),
                        'desc'      => esc_html__('For Aside Header', 'sebian')
                    )
                )
            ),
            array(
                'name'      => 'header_megamenu_styling_sections',
                'title'     => esc_html__('Mega Menu Styling', 'sebian'),
                'icon'      => 'fa fa-bars',
                'fields'    => array(
                    array(
                        'id'        => 'mm_dropdown_bg',
                        'default'   => '#fff',
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Background Color', 'sebian'),
                        'desc'      => esc_html__('For type "DropDown"', 'sebian')
                    ),
                    array(
                        'id'        => 'mm_dropdown_link_color',
                        'default'   => Sebian_Options::get_color_default('body_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Link Color', 'sebian'),
                        'desc'      => esc_html__('For type "DropDown"', 'sebian')
                    ),
                    array(
                        'id'        => 'mm_dropdown_link_bg',
                        'default'   => 'rgba(0,0,0,0)',
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Link Background Color', 'sebian'),
                        'desc'      => esc_html__('For type "DropDown"', 'sebian')
                    ),
                    array(
                        'id'        => 'mm_dropdown_link_hover_color',
                        'default'   => Sebian_Options::get_color_default('secondary_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Link Hover Color', 'sebian'),
                        'desc'      => esc_html__('For type "DropDown"', 'sebian')
                    ),
                    array(
                        'id'        => 'mm_dropdown_link_hover_bg',
                        'default'   => 'rgba(0,0,0,0)',
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Link Hover Background Color', 'sebian'),
                        'desc'      => esc_html__('For type "DropDown"', 'sebian')
                    ),
                    array(
                        'id'        => 'mm_wide_dropdown_bg',
                        'default'   => '#fff',
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Background Color', 'sebian'),
                        'desc'      => esc_html__('For type "Wide"', 'sebian')
                    ),
                    array(
                        'id'        => 'mm_wide_dropdown_heading_color',
                        'default'   => Sebian_Options::get_color_default('heading_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Heading Color', 'sebian'),
                        'desc'      => esc_html__('For type "Wide"', 'sebian')
                    ),
                    array(
                        'id'        => 'mm_wide_dropdown_link_color',
                        'default'   => Sebian_Options::get_color_default('body_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Link Color', 'sebian'),
                        'desc'      => esc_html__('For type "Wide"', 'sebian')
                    ),
                    array(
                        'id'        => 'mm_wide_dropdown_link_bg',
                        'default'   => 'rgba(0,0,0,0)',
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Link Background Color', 'sebian'),
                        'desc'      => esc_html__('For type "Wide"', 'sebian')
                    ),
                    array(
                        'id'        => 'mm_wide_dropdown_link_hover_color',
                        'default'   => Sebian_Options::get_color_default('secondary_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Link Hover Color', 'sebian'),
                        'desc'      => esc_html__('For type "Wide"', 'sebian')
                    ),
                    array(
                        'id'        => 'mm_wide_dropdown_link_hover_bg',
                        'default'   => 'rgba(0,0,0,0)',
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Link Hover Background Color', 'sebian'),
                        'desc'      => esc_html__('For type "Wide"', 'sebian')
                    )
                )
            ),
            array(
                'name'      => 'header_mobile_styling_sections',
                'title'     => esc_html__('Header Mobile', 'sebian'),
                'icon'      => 'fa fa-bars',
                'fields'    => array(
                    array(
                        'id'        => 'header_mb_background',
                        'default'   => '#fff',
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Background Color', 'sebian'),
                        'desc'      => esc_html__('For Mobile Header', 'sebian')
                    ),
                    array(
                        'id'        => 'header_mb_text_color',
                        'default'   => Sebian_Options::get_color_default('body_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Text Color', 'sebian'),
                        'desc'      => esc_html__('For Mobile Header', 'sebian')
                    ),
                    array(
                        'type'    => 'notice',
                        'class'   => 'no-format la-section-title',
                        'content' => sprintf('<h3>%s</h3>', esc_html__('Mobile Menu Styling', 'sebian'))
                    ),
                    array(
                        'id'        => 'mb_background',
                        'default'   => '#fff',
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Background Color', 'sebian'),
                        'desc'      => esc_html__('For Mobile Menu', 'sebian')
                    ),
                    array(
                        'id'        => 'mb_lv_1_color',
                        'default'   => Sebian_Options::get_color_default('secondary_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Menu Level 1 Color', 'sebian'),
                        'desc'      => esc_html__('For Mobile Menu', 'sebian')
                    ),
                    array(
                        'id'        => 'mb_lv_1_bg_color',
                        'default'   => 'rgba(0,0,0,0)',
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Menu Level 1 Background Color', 'sebian'),
                        'desc'      => esc_html__('For Mobile Menu', 'sebian')
                    ),
                    array(
                        'id'        => 'mb_lv_1_hover_color',
                        'default'   => Sebian_Options::get_color_default('primary_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Menu Level 1 Hover Color', 'sebian'),
                        'desc'      => esc_html__('For Mobile Menu', 'sebian')
                    ),
                    array(
                        'id'        => 'mb_lv_1_hover_bg_color',
                        'default'   => 'rgba(0,0,0,0)',
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Menu Level 1 Hover Background Color', 'sebian'),
                        'desc'      => esc_html__('For Mobile Menu', 'sebian')
                    ),
                    array(
                        'id'        => 'mb_lv_2_color',
                        'default'   => Sebian_Options::get_color_default('secondary_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Menu Level 2 Color', 'sebian'),
                        'desc'      => esc_html__('For Mobile Menu', 'sebian')
                    ),
                    array(
                        'id'        => 'mb_lv_2_bg_color',
                        'default'   => 'rgba(0,0,0,0)',
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Menu Level 2 Background Color', 'sebian'),
                        'desc'      => esc_html__('For Mobile Menu', 'sebian')
                    ),
                    array(
                        'id'        => 'mb_lv_2_hover_color',
                        'default'   => '#fff',
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Menu Level 2 Hover Color', 'sebian'),
                        'desc'      => esc_html__('For Mobile Menu', 'sebian')
                    ),
                    array(
                        'id'        => 'mb_lv_2_hover_bg_color',
                        'default'   => Sebian_Options::get_color_default('primary_color'),
                        'type'      => 'color_picker',
                        'title'     => esc_html__('Menu Level 2 Hover Background Color', 'sebian'),
                        'desc'      => esc_html__('For Mobile Menu', 'sebian')
                    )
                )
            )
        )
    );
    return $sections;
}